@@ -1,5 +1,5 @@
 #!/bin/sh
 PRIMER3_DIR=/usr/local/bin
 export PRIMER3_DIR
-perl -Ilib mcprimers.pl
+perl mcprimers.pl
 
